/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007 - INRIA - Allan Cornet
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*--------------------------------------------------------------------------*/ 
#ifndef _TERMINATEGRAPHICS_H__
#define _TERMINATEGRAPHICS_H__
#include "BOOL.h"
#include "dynlib_graphics.h"

GRAPHICS_IMPEXP BOOL TerminateGraphics(void);

#endif /* _TERMINATEGRAPHICS_H__ */
/*--------------------------------------------------------------------------*/ 
